//                                                                  
// Copyright  2013 Lidor Systems.
// All Rights Reserved.
//
// This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
// either express or implied.                        
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace IntegralUI_WinForms_Samples
{
    public partial class Form1 : Form
    {
        #region Variables
        private int[] randomInts = null;
        private int nodeCount = 0;
        #endregion

        #region Initialize
        public Form1()
        {
            InitializeComponent();

            CreateLabelContent();

            InitList();
        }

        private void CreateLabelContent()
        {
            String content = "<div style=\"font:Verdana,9,r\">In this sample we are demonstrating how to expand nodes by:<br></br>";
            content += "<b>   1. Position mouse cursor over node space</b><br></br>";
            content += "<b>   2. Clicking node's text</b><br></br><br></br>";
            content += "If you want to see how node expands in first case, just hover with mouse cursor over some node. After inital delay of 500ms, the node will expand.<br></br>";
            content += "In order to see the second case in action, first check the radio button on right panel to switch functionality. Then click inside text space of some node. In this case, the node will expand or collapse only when it is clickied inside its text space.";
            content += "</div>";

            this.labelInfo.Content = content;
        }

        private void InitList()
        {
            this.treeView1.SuspendUpdate();

            nodeCount = 0;

            // Create set of random integer values used to generate random number of child nodes
            randomInts = CreateRandomInts();

            // Create random tree hierarchy
            CreateNode(this.treeView1.RootNode, "", 0);

            this.treeView1.ResumeUpdate();
        }

        private void CreateNode(LidorSystems.IntegralUI.Lists.TreeNode parentNode, String prefix, int level)
        {
            if (level == 5)
                return;

            int limit = randomInts[nodeCount % 99];
            if (level == 0)
                limit = 100;

            LidorSystems.IntegralUI.Lists.TreeNode node = null;
            for (int i = 1; i <= limit; i++)
            {
                node = new LidorSystems.IntegralUI.Lists.TreeNode("Node " + prefix + i.ToString());

                parentNode.Nodes.Add(node);
                nodeCount++;

                CreateNode(node, prefix + i.ToString(), level + 1);
            }
        }

        private int[] CreateRandomInts()
        {
            int[] rand = new int[100];
            Random gen = new Random();
            for (int i = 0; i < rand.Length; i++)
                rand[i] = gen.Next(0, 5);

            return rand;
        }
        #endregion

        #region Expand on Hover
        private void treeView1_ItemMouseHover(object sender, LidorSystems.IntegralUI.ObjectEventArgs e)
        {
            if (rbExpandHover.Checked)
            {
                // Check whether the object passed to this event is a TreeNode
                // If it is a TreeNode, expand its content
                if (e.Object is LidorSystems.IntegralUI.Lists.TreeNode)
                {
                    LidorSystems.IntegralUI.Lists.TreeNode node = (LidorSystems.IntegralUI.Lists.TreeNode)e.Object;

                    node.Expand();
                }
            }
        }
        #endregion

        #region Expand on Click
        private void treeView1_Click(object sender, EventArgs e)
        {
            if (rbExpandClick.Checked)
            {
                // Retrieve the current position of mouse cursor
                Point mousePos = this.treeView1.ContentPanel.PointToClient(Control.MousePosition);

                // Get a node at which mouse cursor points to
                LidorSystems.IntegralUI.Lists.TreeNode node = this.treeView1.GetNodeAt(mousePos);
                if (node != null)
                {
                    // Retrieve the space of node text and check whether the click was made inside it
                    // If it is expand or collapse the node
                    RectangleF textArea = node.TextRect;
                    if (textArea.Contains(mousePos))
                        node.Toggle();
                }
            }
        }
        #endregion
    }
}